﻿local Engine, Api, Locale, Settings = unpack(Immersive)

local Default = Engine:GetModule("Default")

-- Condition: Does the player have 1 or more buffs active?
function Default:IsBuffActive()
	return select(1, UnitBuff("player", 1)) ~= nil
end

-- Condition: Does the player have 1 or more debuffs active?
function Default:IsDebuffActive()
	return select(1, UnitDebuff("player", 1)) ~= nil
end

-- Condition: Does the player have less than full health?
function Default:IsHungry()
	return UnitHealth("player") < UnitHealthMax("player")
end

-- Condition: Is the player in an arena?
function Default:IsInArena()
	return select(2, IsInInstance()) == "arena"
end

-- Condition: Is the player in a battleground?
function Default:IsInBattleground()
	return select(2, IsInInstance()) == "pvp"
end

-- Condition: Is the player in combat?
function Default:IsInCombat()
	return UnitAffectingCombat("player")
end

-- Condition: Is the player in a pet battle?
function Default:IsInPetBattle()
	return C_PetBattles.IsInBattle()
end

-- Condition: Is anyone in the player's party hungry?
function Default:IsPartyHungry()
	if UnitInRaid("player") and GetSpecializationInfo(GetSpecialization()) == "HEALER" then
		for i = 1, 4 do
			local member = "party"..i
			if UnitExists(member) then
				return UnitHealth(member) < UnitHealthMax(member)
			end
		end
	end
	return false
end

-- Condition: Is anyone in the player's raid hungry?
function Default:IsRaidHungry()
	if UnitInRaid("player") and GetSpecializationInfo(GetSpecialization()) == "HEALER" then
		for i = 1, 40 do
			local member = "raid"..i
			if UnitExists(member) then
				return UnitHealth(member) < UnitHealthMax(member)
			end
		end
	end
	return false
end

-- Condition: Does the player have a target?
function Default:IsTargetAvailable()
	return UnitExists("target")
end

-- Condition: Is the player's target an enemy?
function Default:IsTargetEnemy()
	return UnitIsEnemy("player", "target")
end

-- Condition: Is the player's target hostile?
function Default:IsTargetHostile()
	local reaction = UnitReaction("player", "target")
	return reaction ~= nil and reaction <= 4 -- 4 is Neutral
end

-- Condition: Is the player's target a party member?
function Default:IsTargetInParty()
	return UnitInParty("target")
end

-- Condition: Is the player's target a raid member?
function Default:IsTargetInRaid()
	return UnitInRaid("target")
end

-- Condition: Is the player's target controlled by another player?
function Default:IsTargetPlayer()
	return UnitPlayerControlled("target")
end

-- Condition: Does the player have less than full mana? (Mana classes only)
function Default:IsThirsty()
	if select(1, UnitPowerType("player")) == SPELL_POWER_MANA then
		return UnitPower("player") < UnitPowerMax("player")
	end
	return false
end