﻿local Engine, Api, Locale, Settings = unpack(Immersive)

local ElvUI = Engine:GetModule("ElvUI")

-- Registers the ElvUI options frame
function ElvUI:OnRegisterOptions()
	local settings = Settings:Get(self.Name)
	local panel = CreateFrame("Frame", string.format("%s%sOptionsFrame", Engine.AddOnName, self.Name))

	panel.name = Locale.ELVUI_OPTIONS_NAME
	panel.parent = Locale.CONFIG_OPTIONS_NAME

	-- Description
	local title = panel:CreateFontString("Title", "ARTWORK", "GameFontNormalLarge")
	title:SetJustifyH("LEFT")
	title:SetJustifyV("TOP")
	title:SetPoint("TOPLEFT", panel, "TOPLEFT", 16, -16)
	title:SetText(Locale.ELVUI_OPTIONS_TITLE)

	local subText = panel:CreateFontString("Title", "ARTWORK", "GameFontHighlightSmall")
	subText:SetJustifyH("LEFT")
	subText:SetJustifyV("TOP")
	subText:SetPoint("TOPLEFT", title, "BOTTOMLEFT", 0, -8)
	subText:SetPoint("RIGHT", panel, "RIGHT", -32, 0)
	subText:SetText(Locale.ELVUI_OPTIONS_SUBTEXT)

	-- Controls: Enable
	local enabled = CreateFrame("CheckButton", string.format("%s%sEnableCheckButton", Engine.AddOnName, self.Name), panel, "InterfaceOptionsCheckButtonTemplate")
	enabled:SetPoint("TOPLEFT", subText, "BOTTOMLEFT", -2, -8)
	enabled:SetChecked(settings.Enabled)
	enabled:SetScript("OnClick", function(self)
		settings.Enabled = self:GetChecked()
	end)
	enabled:SetScript("OnEnter", function(self)
		if self.Tooltip then
			GameTooltip:SetOwner(self, "ANCHOR_RIGHT");
			GameTooltip:SetText(self.Tooltip, nil, nil, nil, nil, true);
		end
	end)
	enabled.Text:SetText(Locale.ELVUI_OPTIONS_ENABLED_TEXT)
	enabled.Tooltip = Locale.ELVUI_OPTIONS_ENABLED_TOOLTIP
	
	InterfaceOptions_AddCategory(panel)
end